This is a cron job scheduler for Node.

It forks new processes for each job resulting in zero impact on application performance.

Otherwise, the inherently single-threaded node server may be blocked
until an I/O intensive cron job finishes.


## Table of Contents

- [Install](#install)
- [Setup](#setup)
- [API](#api)
- [Future releases](#future-releases)


## Install

```sh
$ npm install node-cron-job
```


## Setup

The jobs have to be declared in a separate module such as:
```js
// jobs.js

exports.first_job = {
    
    after: {                // Configuring this job to run after this period.
        seconds: 2,
        minutes:2,
        hours: 1,
        days: 3
    },
    job: function () {
        console.log("first_job");
    }
}

exports.second_job = {
    
    on: "*/2 * * * * *",    // Cron tab instruction.
    job: function () {
        console.log("second_job");
    }
}
```

Next, the module may be used any where within your code to indicate the absolute path to the 
jobs file and explicit instructions to start those jobs. Example:

```js
// main.js

var cronjob = require('node-cron-job');


cronjob.setJobsPath(__dirname + '/jobs.js');  // Absolute path to the jobs module.

cronjob.startJob('first_job');

cronjob.startJob('second_job');
```


## API

Each job exported by the jobs module can have the following objects:

* `on`: The cron tab instruction string that defines the schedule.

Please see [crontab.org](http://crontab.org/).

[cron-parser](https://www.npmjs.com/package/cron-parser) is used to parse these.

* `after`: A easier-to-use but less expressive way to schedule a job. It defines
the time after which the job is supposed to run, periodically. Example:

```txt
after: {
    hours: 2,
    days: 10
},
```

* `job`: The job closure that is to be scheduled.


The module includes these methods:

* `setJobsPath(abs_path)`: Sets the absolute path to the jobs module.

* `startJob(job_name)`: Starts the given job.

* `startAllJobs()`: Starts all jobs defined in the jobs module.


## Future releases

Currently there is a problem with jobs that have a number of weeks in between them.

It'll be fixed soon.

You can send your feedback or requests to [uashraf588@gmail.com](mailto:uashraf588@gmail.com)
